@@ -22,6 +22,6 @@ detach("R.oo")
   }
 
   assign(pkgname, pkg, pos=pos);
-  cat(getName(pkg), " v", getVersion(pkg), " (", getDate(pkg), ")",
-      " successfully loaded. See ?", pkgname, " for help.\n", sep="");
+  packageStartupMessage(getName(pkg), " v", getVersion(pkg), " (", 
+    getDate(pkg), ") successfully loaded. See ?", pkgname, " for help.");
 }
